==> rc-ui-lib-0.1.29.tgz: package/es/flex/Flex.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
var _excluded = ["direction", "wrap", "justify", "align", "gutter", "style", "className", "children"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useMemo } from 'react';
import classnames from 'classnames';
import FlexContext from './FlexContext';
import { createNamespace } from '../utils';

var _createNamespace = createNamespace('flexbox'),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];

var Flex = function Flex(props) {
  var direction = props.direction,
      wrap = props.wrap,
      justify = props.justify,
      align = props.align,
      gutter = props.gutter,
      style = props.style,
      className = props.className,
      children = props.children,
      rest = _objectWithoutProperties(props, _excluded);

  var getGutter = useMemo(function () {
    return Array.isArray(gutter) ? gutter : [gutter, 0];
  }, [gutter]);

  var rowStyle = _objectSpread(_objectSpread(_objectSpread({}, getGutter[0] > 0 ? {
    marginLeft: getGutter[0] / -2,
    marginRight: getGutter[0] / -2
  } : {}), getGutter[1] > 0 ? {
    marginTop: getGutter[1] / -2,
    marginBottom: getGutter[1] / 2
  } : {}), style);

  var wrapCls = classnames(className, bem([direction, wrap, justify ? "justify-".concat(justify) : false, align ? "align-".concat(align) : false]));
  return /*#__PURE__*/React.createElement(FlexContext.Provider, {
    value: {
      gutter: getGutter
    }
  }, /*#__PURE__*/React.createElement("div", _extends({
    className: wrapCls,
    style: rowStyle
  }, rest), children));
};

Flex.defaultProps = {
  gutter: 0
};
export default Flex;

==> rc-ui-lib-0.1.35.tgz: package/es/flex/Flex.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["direction", "wrap", "justify", "align", "gutter", "style", "className", "children"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext, useMemo } from 'react';
import classnames from 'classnames';
import FlexContext from './FlexContext';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var Flex = function Flex(props) {
  var direction = props.direction,
      wrap = props.wrap,
      justify = props.justify,
      align = props.align,
      gutter = props.gutter,
      style = props.style,
      className = props.className,
      children = props.children,
      rest = _objectWithoutProperties(props, _excluded);

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('flexbox', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var getGutter = useMemo(function () {
    return Array.isArray(gutter) ? gutter : [gutter, 0];
  }, [gutter]);

  var rowStyle = _objectSpread(_objectSpread(_objectSpread({}, getGutter[0] > 0 ? {
    marginLeft: getGutter[0] / -2,
    marginRight: getGutter[0] / -2
  } : {}), getGutter[1] > 0 ? {
    marginTop: getGutter[1] / -2,
    marginBottom: getGutter[1] / 2
  } : {}), style);

  var wrapCls = classnames(className, bem([direction, wrap, justify ? "justify-".concat(justify) : false, align ? "align-".concat(align) : false]));
  return /*#__PURE__*/React.createElement(FlexContext.Provider, {
    value: {
      gutter: getGutter
    }
  }, /*#__PURE__*/React.createElement("div", _extends({
    className: wrapCls,
    style: rowStyle
  }, rest), children));
};

Flex.defaultProps = {
  gutter: 0
};
export default Flex;
